﻿Public Class RecentFilesComboBox
    Inherits ComboBox

    Private Const MaxRecentFiles As Integer = 10
    Private recentFiles As New List(Of String)

    Public Sub New()
        ' -----------------------------------------------------------
        Me.AllowDrop = True
        AddHandler Me.DragEnter, AddressOf ComboBox_DragEnter
        AddHandler Me.DragDrop, AddressOf ComboBox_DragDrop
    End Sub

    Private Sub ComboBox_DragEnter(ByVal sender As Object, ByVal e As DragEventArgs)
        If e.Data.GetDataPresent(DataFormats.FileDrop) Then
            e.Effect = DragDropEffects.Copy
        End If
    End Sub

    Private Sub ComboBox_DragDrop(ByVal sender As Object, ByVal e As DragEventArgs)
        Dim files As String()
        files = CType(e.Data.GetData(DataFormats.FileDrop), String())
        If files.Length > 0 Then
            Me.AddRecentFile(files(0))
            Me.Text = files(0)
            Me.Refresh()
        End If
    End Sub

    Friend Sub AddRecentFile(ByVal file As String)
        ' -------------------------------------- Remove file if already exists
        recentFiles.Remove(file)
        ' -------------------------------------- Add file at start
        recentFiles.Insert(0, file)
        ' -------------------------------------- Remove oldest files
        If recentFiles.Count > MaxRecentFiles Then
            recentFiles.RemoveAt(MaxRecentFiles)
        End If
        ' -------------------------------------- Update the ComboBox
        Me.Items.Clear()
        Me.Items.AddRange(recentFiles.ToArray())
    End Sub

    Public Sub SaveRecentFiles(ByVal fileName As String)
        Using writer As New IO.StreamWriter(Application.StartupPath + "\" + fileName)
            For Each file As String In recentFiles
                writer.WriteLine(file)
            Next
        End Using
    End Sub

    Public Sub LoadRecentFiles(ByVal fileName As String)
        Dim f As String = Application.StartupPath + "\" + fileName
        If Not IO.File.Exists(f) Then Return
        Using reader As New IO.StreamReader(f)
            While Not reader.EndOfStream
                Dim s As String = reader.ReadLine().Trim
                If s <> "" Then AddRecentFile(s)
            End While
        End Using
    End Sub

End Class
